timeintervaltools.explode_intervals_uncompactly
===============================================

.. autofunction:: abjad.tools.timeintervaltools.explode_intervals_uncompactly.explode_intervals_uncompactly
